@@ -35,6 +35,7 @@ from typing import Any
 import argcomplete
 import pkg_resources
 import requests
+from loguru import logger
 
 try:
     from colorama import init
@@ -66,22 +67,24 @@ def status_handler(args: Any) -> None:
     """Get platform status."""
 
     client_version = pkg_resources.get_distribution("cr_api_client").version
-    print("[+] cr_api_client version: {}".format(client_version))
+    logger.info("[+] cr_api_client version: {}".format(client_version))
 
-    print("[+] Platform status")
+    logger.info("[+] Platform status")
 
     # Core API
-    print("  [+] Core API")
-    print("    [+] address: {}".format(core_api.CORE_API_URL))
+    logger.info("  [+] Core API")
+    logger.info("    [+] address: {}".format(core_api.CORE_API_URL))
     try:
         core_api_version = core_api.get_version()
     except requests.exceptions.ConnectionError:
-        print("    [-] API status: " + colored("not running !", "white", "on_red"))
+        logger.warning(
+            "    [-] API status: " + colored("not running !", "white", "on_red")
+        )
     else:
-        print("    [+] API status: " + colored("OK", "grey", "on_green"))
-        print("    [+] version: {}".format(core_api_version))
+        logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
+        logger.info("    [+] version: {}".format(core_api_version))
         if client_version != core_api_version:
-            print(
+            logger.info(
                 "    [-] "
                 + colored(
                     "warning: Core API version ({}) mismatchs with cr_api_client version ({})".format(
@@ -96,23 +99,27 @@ def status_handler(args: Any) -> None:
     try:
         status = core_api.virtclient_status()
     except Exception:
-        print("    [-] compute status: " + colored("not running !", "white", "on_red"))
+        logger.warning(
+            "    [-] compute status: " + colored("not running !", "white", "on_red")
+        )
     else:
-        print("    [+] compute status: " + colored("OK", "grey", "on_green"))
-        print("    [+] available slots: {}".format(status["nb_slots"]))
+        logger.info("    [+] compute status: " + colored("OK", "grey", "on_green"))
+        logger.info("    [+] available slots: {}".format(status["nb_slots"]))
 
     # Scenario API
-    print("  [+] Scenario API")
-    print("    [+] address: {}".format(scenario_api.SCENARIO_API_URL))
+    logger.info("  [+] Scenario API")
+    logger.info("    [+] address: {}".format(scenario_api.SCENARIO_API_URL))
     try:
         scenario_api_version = scenario_api.get_version()
     except requests.exceptions.ConnectionError:
-        print("    [-] API status: " + colored("not running !", "white", "on_red"))
+        logger.warning(
+            "    [-] API status: " + colored("not running !", "white", "on_red")
+        )
     else:
-        print("    [+] API status: " + colored("OK", "grey", "on_green"))
-        print("    [+] version: {}".format(scenario_api_version))
+        logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
+        logger.info("    [+] version: {}".format(scenario_api_version))
         if client_version != scenario_api_version:
-            print(
+            logger.info(
                 "    [-] "
                 + colored(
                     "warning: Scenario API version ({}) mismatchs with cr_api_client version ({})".format(
@@ -124,17 +131,19 @@ def status_handler(args: Any) -> None:
             )
 
     # Provisioning API
-    print("  [+] Provisioning API")
-    print("    [+] address: {}".format(provisioning_api.PROVISIONING_API_URL))
+    logger.info("  [+] Provisioning API")
+    logger.info("    [+] address: {}".format(provisioning_api.PROVISIONING_API_URL))
     try:
         provisioning_api_version = provisioning_api.get_version()
     except requests.exceptions.ConnectionError:
-        print("    [-] API status: " + colored("not running !", "white", "on_red"))
+        logger.warning(
+            "    [-] API status: " + colored("not running !", "white", "on_red")
+        )
     else:
-        print("    [+] API status: " + colored("OK", "grey", "on_green"))
-        print("    [+] version: {}".format(provisioning_api_version))
+        logger.info("    [+] API status: " + colored("OK", "grey", "on_green"))
+        logger.info("    [+] version: {}".format(provisioning_api_version))
         if client_version != provisioning_api_version:
-            print(
+            logger.info(
                 "    [-] "
                 + colored(
                     "warning: Provisioning API version ({}) mismatchs with cr_api_client version ({})".format(
@@ -146,8 +155,8 @@ def status_handler(args: Any) -> None:
             )
 
     # # Testing frontend
-    # print("  [+] Frontend")
-    # print(
+    # logger.info("  [+] Frontend")
+    # logger.info(
     #     "    [+] Address: {}:{}".format(
     #         cyber_range_conf.frontend["listen_host"],
     #         cyber_range_conf.frontend["listen_port"],
@@ -163,12 +172,12 @@ def status_handler(args: Any) -> None:
     #     if result.status_code != 200:
     #         raise Exception("Error detected in frontend response")
     # except requests.exceptions.ConnectionError:
-    #     print("    [+] Status: not running !")
+    #     logger.info("    [+] Status: not running !")
     # except Exception:
-    #     print("    [+] Status: not working properly !")
+    #     logger.info("    [+] Status: not working properly !")
     #     return
     # else:
-    #     print("    [+] Status: OK")
+    #     logger.info("    [+] Status: OK")
 
 
 #
@@ -177,7 +186,7 @@ def status_handler(args: Any) -> None:
 def init_handler(args: Any) -> None:
     """Process initialization of mysql db and snapshots path."""
 
-    print("[+] Checking version")
+    logger.info("[+] Checking version")
 
     # Check version
     client_version = pkg_resources.get_distribution("cr_api_client").version
@@ -185,10 +194,12 @@ def init_handler(args: Any) -> None:
     try:
         core_api_version = core_api.get_version()
     except requests.exceptions.ConnectionError:
-        print("    [-] API status: " + colored("not running !", "white", "on_red"))
+        logger.info(
+            "    [-] API status: " + colored("not running !", "white", "on_red")
+        )
         sys.exit(1)
     if client_version != core_api_version:
-        print(
+        logger.info(
             colored(
                 "cr_api_client version ({}) mismatchs with Core API version ({})".format(
                     client_version, core_api_version
@@ -199,10 +210,10 @@ def init_handler(args: Any) -> None:
         )
         sys.exit(1)
     else:
-        print("  [+] client API version: {}".format(client_version))
-        print("  [+] server API version: {}".format(core_api_version))
+        logger.info("  [+] client API version: {}".format(client_version))
+        logger.info("  [+] server API version: {}".format(core_api_version))
 
-    print(
+    logger.info(
         "[+] Initialize Core API (reset database, stop VMs, stop Docker containers, delete snaphots, ...)"
     )
     core_api.reset()
@@ -213,7 +224,7 @@ def init_handler(args: Any) -> None:
 #
 def baseboxes_list_handler(args: Any) -> None:
     """List available baseboxes, for use in simulations."""
-    print(
+    logger.info(
         "[+] List of baseboxes, ordered by system_type and operating_system (available baseboxes are in green, with path mentioned)"
     )
     baseboxes = core_api.fetch_baseboxes()
@@ -228,7 +239,7 @@ def baseboxes_list_handler(args: Any) -> None:
             "system_type" not in basebox.keys()
             or "operating_system" not in basebox.keys()
         ):
-            print(
+            logger.info(
                 f"[-] The following basebox does not contain the required information (system_type or operating_system): {basebox}"
             )
             continue
@@ -245,7 +256,7 @@ def baseboxes_list_handler(args: Any) -> None:
 
     # Display baseboxes ordered by system_type and operating_system
     for current_system_type in system_type_list:
-        print("  [+] " + colored(f"{current_system_type}", attrs=["bold"]))
+        logger.info("  [+] " + colored(f"{current_system_type}", attrs=["bold"]))
 
         for (system_type, operating_system_list) in operating_system_dict.items():
             if current_system_type == system_type:
@@ -254,7 +265,9 @@ def baseboxes_list_handler(args: Any) -> None:
                 operating_system_list = sorted(list(operating_system_list))
 
                 for operating_system in operating_system_list:
-                    print("    [+] " + colored(f"{operating_system}", attrs=["bold"]))
+                    logger.info(
+                        "    [+] " + colored(f"{operating_system}", attrs=["bold"])
+                    )
 
                     for basebox in baseboxes:
                         if (
@@ -263,7 +276,7 @@ def baseboxes_list_handler(args: Any) -> None:
                         ):
 
                             # Check if basebox is in local catalog
-                            print(
+                            logger.info(
                                 "      [+] '{}': {} (role: {}, language: {})".format(
                                     basebox["id"],
                                     basebox["description"],
@@ -278,9 +291,9 @@ def baseboxes_list_handler(args: Any) -> None:
 #
 def baseboxes_reload_handler(args: Any) -> None:
     """List available baseboxes, for use in simulations."""
-    print("[+] Reload list of available baseboxes")
+    logger.info("[+] Reload list of available baseboxes")
     core_api.reload_baseboxes()
-    print("[+] Done")
+    logger.info("[+] Done")
 
 
 #
@@ -292,24 +305,26 @@ def baseboxes_verify_handler(args: Any) -> None:
     requested_basebox_id = args.basebox_id
 
     if requested_basebox_id is None:
-        print("[+] Verifying the checksums of available baseboxes")
+        logger.info("[+] Verifying the checksums of available baseboxes")
         baseboxes = core_api.fetch_baseboxes()
         for basebox in baseboxes:
             result = core_api.verify_basebox(basebox["id"])
-            print(
+            logger.info(
                 "  [+] {} has the correct checksum: {}".format(
                     result["basebox_id"], result["valid_checksum"]
                 )
             )
     else:
-        print("[+] Verifying the checksum of basebox {}".format(requested_basebox_id))
+        logger.info(
+            "[+] Verifying the checksum of basebox {}".format(requested_basebox_id)
+        )
         result = core_api.verify_basebox(requested_basebox_id)
-        print(
+        logger.info(
             "  [+] {} has the correct checksum: {}".format(
                 result["basebox_id"], result["valid_checksum"]
             )
         )
-    print("[+] Done")
+    logger.info("[+] Done")
 
 
 #
@@ -317,11 +332,11 @@ def baseboxes_verify_handler(args: Any) -> None:
 #
 def websites_list_handler(args: Any) -> None:
     """List available websites, for use in simulations."""
-    print("[+] List of available websites")
+    logger.info("[+] List of available websites")
     websites = core_api.fetch_websites()
 
     for website in websites:
-        print("  [+] {}".format(website))
+        logger.info("  [+] {}".format(website))
 
 
 #
@@ -356,14 +371,14 @@ def simu_create_handler(args: Any) -> None:
                 "Either a topology or a basebox ID is required to create a new simulation"
             )
 
-        print("[+] Created simulation ID: '{}'".format(id_simulation))
+        logger.info("[+] Created simulation ID: '{}'".format(id_simulation))
     except Exception as e:
-        print(f"Error when creating new simulation: '{e}'")
+        logger.info(f"Error when creating new simulation: '{e}'")
         sys.exit(1)
     finally:
         t2 = time.time()
         time_elapsed = t2 - t1
-        print("[+] Time elapsed: {0:.2f} seconds".format(time_elapsed))
+        logger.info("[+] Time elapsed: {0:.2f} seconds".format(time_elapsed))
 
 
 #
@@ -385,7 +400,7 @@ def provisioning_execute_handler(args: Any) -> None:
             id_simulation, provisioning_configuration_file, debug=debug
         )
     except Exception as e:
-        print(f"Error during provisioning: '{e}'")
+        logger.info(f"Error during provisioning: '{e}'")
         sys.exit(1)
 
 
@@ -441,7 +456,7 @@ def provisioning_ansible_handler(args: Any) -> None:
     except Exception as e:
         error_msg = str(e)
         error_msg = error_msg.replace("\\n", "\n")
-        print(f"Error during provisioning: {error_msg}")
+        logger.info(f"Error during provisioning: {error_msg}")
         sys.exit(1)
 
 
@@ -457,7 +472,7 @@ def scenario_play_handler(args: Any) -> None:
     debug_mode = args.scenario_debug_mode
     speed = args.scenario_speed
 
-    print(
+    logger.info(
         "[+] Playing scenario '{}' on simulation id '{}'".format(
             scenario_path, id_simulation
         )
@@ -468,7 +483,7 @@ def scenario_play_handler(args: Any) -> None:
             id_simulation, scenario_path, debug_mode, speed, file_results
         )
     except Exception as e:
-        print(f"Error when playing scenario: '{e}'")
+        logger.info(f"Error when playing scenario: '{e}'")
         sys.exit(1)
 
 
@@ -480,9 +495,9 @@ def scenario_status_handler(args: Any) -> None:
     # Parameters
     id_simulation = args.id_simulation
 
-    print("[+] Get scenario status on simulation id '{}'".format(id_simulation))
+    logger.info("[+] Get scenario status on simulation id '{}'".format(id_simulation))
     status = scenario_api.scenario_status(id_simulation)
-    print("  [+] Current status: {}".format(status["status"]))
+    logger.info("  [+] Current status: {}".format(status["status"]))
 
 
 #
@@ -499,14 +514,14 @@ def simu_run_handler(args: Any) -> None:
     try:
         core_api.start_simulation(id_simulation, use_install_time)
     except Exception as e:
-        print(f"Error when starting simulation: '{e}'")
+        logger.info(f"Error when starting simulation: '{e}'")
         sys.exit(1)
     else:
-        print("[+] Simulation is running...")
+        logger.info("[+] Simulation is running...")
     finally:
         t2 = time.time()
         time_elapsed = t2 - t1
-        print("[+] Time elapsed: {0:.2f} seconds".format(time_elapsed))
+        logger.info("[+] Time elapsed: {0:.2f} seconds".format(time_elapsed))
 
 
 #
@@ -525,24 +540,24 @@ def simu_status_handler(args: Any) -> None:
         ):
             id_simulation = simulation["id"]
 
-            print("[+] simulation id {}:".format(id_simulation))
-            print("  [+] name: {}".format(simulation["name"]))
-            print("  [+] status: {}".format(simulation["status"]))
+            logger.info("[+] simulation id {}:".format(id_simulation))
+            logger.info("  [+] name: {}".format(simulation["name"]))
+            logger.info("  [+] status: {}".format(simulation["status"]))
 
             # Fetch associated nodes
             nodes = core_api.fetch_nodes(id_simulation)
 
-            print("  [+] nodes:")
+            logger.info("  [+] nodes:")
             for node in nodes:
-                print(
+                logger.info(
                     "    [+] ID: {}, name: {}, type: {}".format(
                         node["id"], node["name"], node["type"]
                     )
                 )
-                print("      [+] status: {}".format(node["status"]))
+                logger.info("      [+] status: {}".format(node["status"]))
 
                 if node["type"] == "virtual_machine":
-                    print(
+                    logger.info(
                         "      [+] node stats: {} Mo, {} core(s)".format(
                             node["memory_size"],
                             node["nb_proc"],
@@ -550,50 +565,50 @@ def simu_status_handler(args: Any) -> None:
                     )
 
                     # fetch basebox name
-                    print(
+                    logger.info(
                         "      [+] basebox: {}".format(
                             node["basebox_id"],
                         )
                     )
-                    print(
+                    logger.info(
                         "      [+] roles: {}".format(
                             node["roles"],
                         )
                     )
-                    print(
+                    logger.info(
                         "      [+] current basebox path: {}".format(node["hard_drive"])
                     )
-                    print("      [+] uuid: {}".format(node["system_uid"]))
-                    print("      [+] VNC port: {}".format(node["vnc_port"]))
+                    logger.info("      [+] uuid: {}".format(node["system_uid"]))
+                    logger.info("      [+] VNC port: {}".format(node["vnc_port"]))
                     if node["username"] is not None:
-                        print(
+                        logger.info(
                             "      [+] user account: {}:{}".format(
                                 node["username"], node["password"]
                             )
                         )
                     else:
-                        print("      [+] user account: None")
+                        logger.info("      [+] user account: None")
                     if node["admin_username"] is not None:
-                        print(
+                        logger.info(
                             "      [+] admin account: {}:{}".format(
                                 node["admin_username"], node["admin_password"]
                             )
                         )
                     else:
-                        print("      [+] admin account: None")
+                        logger.info("      [+] admin account: None")
                 elif node["type"] == "docker":
-                    print(
+                    logger.info(
                         "      [+] node stats: {} Mo, {} core(s)".format(
                             node["memory_size"],
                             node["nb_proc"],
                         )
                     )
-                    print(
+                    logger.info(
                         "      [+] docker image: {}".format(
                             node["base_image"],
                         )
                     )
-                    print(
+                    logger.info(
                         "      [+] Interactive port: {}".format(node["terminal_port"])
                     )
 
@@ -602,9 +617,9 @@ def simu_status_handler(args: Any) -> None:
                     network_interfaces = core_api.fetch_node_network_interfaces(
                         node["id"]
                     )
-                    print("      [+] network:")
+                    logger.info("      [+] network:")
                     for network_interface in network_interfaces:
-                        print(
+                        logger.info(
                             "        [+] IP address: {} (at runtime: {}), MAC address: {}".format(
                                 network_interface["ip_address"],
                                 network_interface["ip_address_runtime"],
@@ -612,7 +627,7 @@ def simu_status_handler(args: Any) -> None:
                             )
                         )
                         for domain in network_interface["domains"]:
-                            print(
+                            logger.info(
                                 "          [+] Domain name: '{}'".format(
                                     domain,
                                 )
@@ -629,21 +644,21 @@ def simu_domains_handler(args: Any) -> None:
     try:
         domains_dict = core_api.fetch_domains()
         if len(domains_dict) == 0:
-            print("[+] No domains défined in this simulation")
+            logger.info("[+] No domains défined in this simulation")
         else:
-            print("[+] Domains defined: ")
+            logger.info("[+] Domains defined: ")
             for domain_name, ip_address in domains_dict.items():
-                print(
+                logger.info(
                     "  [+] {}: {}".format(
                         ip_address,
                         domain_name,
                     )
                 )
     except Exception as e:
-        print(f"Error when pausing simulation: '{e}'")
+        logger.info(f"Error when pausing simulation: '{e}'")
         sys.exit(1)
     else:
-        print("Simulation paused")
+        logger.info("Simulation paused")
 
 
 #
@@ -656,10 +671,10 @@ def simu_pause_handler(args: Any) -> None:
     try:
         core_api.pause_simulation(id_simulation)
     except Exception as e:
-        print(f"Error when pausing simulation: '{e}'")
+        logger.info(f"Error when pausing simulation: '{e}'")
         sys.exit(1)
     else:
-        print("Simulation paused")
+        logger.info("Simulation paused")
 
 
 #
@@ -672,10 +687,10 @@ def simu_unpause_handler(args: Any) -> None:
     try:
         core_api.unpause_simulation(id_simulation)
     except Exception as e:
-        print(f"Error when unpausing simulation: '{e}'")
+        logger.info(f"Error when unpausing simulation: '{e}'")
         sys.exit(1)
     else:
-        print("Simulation unpaused")
+        logger.info("Simulation unpaused")
 
 
 #
@@ -688,10 +703,10 @@ def simu_halt_handler(args: Any) -> None:
     try:
         core_api.halt_simulation(id_simulation)
     except Exception as e:
-        print(f"Error when halting simulation: '{e}'")
+        logger.info(f"Error when halting simulation: '{e}'")
         sys.exit(1)
     else:
-        print("Simulation halted")
+        logger.info("Simulation halted")
 
 
 #
@@ -704,10 +719,10 @@ def simu_destroy_handler(args: Any) -> None:
     try:
         core_api.destroy_simulation(id_simulation)
     except Exception as e:
-        print(f"Error when destroying simulation: '{e}'")
+        logger.info(f"Error when destroying simulation: '{e}'")
         sys.exit(1)
     else:
-        print("Simulation destroyed")
+        logger.info("Simulation destroyed")
 
 
 #
@@ -720,11 +735,11 @@ def simu_clone_handler(args: Any) -> None:
     try:
         id_new_simulation = core_api.clone_simulation(id_simulation)
     except Exception as e:
-        print(f"Error when cloning simulation: '{e}'")
+        logger.info(f"Error when cloning simulation: '{e}'")
         sys.exit(1)
     else:
-        print("Simulation cloned")
-        print("Created simulation ID: '{}'".format(id_new_simulation))
+        logger.info("Simulation cloned")
+        logger.info("Created simulation ID: '{}'".format(id_new_simulation))
 
 
 #
@@ -738,10 +753,10 @@ def simu_tap_handler(args: Any) -> None:
     try:
         core_api.tap_simulation(id_simulation, iface)
     except Exception as e:
-        print(f"Error when setting tap on simulation: '{e}'")
+        logger.info(f"Error when setting tap on simulation: '{e}'")
         sys.exit(1)
     else:
-        print("Redirect network traffic to the tap interface")
+        logger.info("Redirect network traffic to the tap interface")
 
 
 #
@@ -755,10 +770,10 @@ def simu_untap_handler(args: Any) -> None:
     try:
         core_api.untap_simulation(id_simulation, iface)
     except Exception as e:
-        print(f"Error when unsetting tap on simulation: '{e}'")
+        logger.info(f"Error when unsetting tap on simulation: '{e}'")
         sys.exit(1)
     else:
-        print("Stop redirection of network traffic to the tap interface")
+        logger.info("Stop redirection of network traffic to the tap interface")
 
 
 #
@@ -771,12 +786,12 @@ def simu_delete_handler(args: Any) -> None:
     try:
         core_api.delete_simulation(id_simulation)
     except Exception as e:
-        print(f"Error when deleting simulation: '{e}'")
+        logger.info(f"Error when deleting simulation: '{e}'")
         sys.exit(1)
     else:
-        print("[+] VMs destroyed")
-        print("[+] VMs snapshots deleted")
-        print("[+] Simulation deleted from database")
+        logger.info("[+] VMs destroyed")
+        logger.info("[+] VMs snapshots deleted")
+        logger.info("[+] Simulation deleted from database")
 
 
 #
@@ -795,9 +810,9 @@ def simu_snap_handler(args: Any) -> None:
         yaml = core_api.snapshot_simulation(id_simulation)
         with open(output_file, "w") as w:
             w.write(yaml)
-        print(f"[+] Snapshot done. Topology file stored at {output_file}")
+        logger.info(f"[+] Snapshot done. Topology file stored at {output_file}")
     except Exception as e:
-        print(f"Error when creating snapshot for simulation: '{e}'")
+        logger.info(f"Error when creating snapshot for simulation: '{e}'")
         sys.exit(1)
 
 
@@ -819,9 +834,11 @@ def topo_add_websites_handler(args: Any) -> None:
         )
         with open(output_topology_file, "w") as w:
             w.write(topology_yaml)
-        print(f"[+] Topology updated. New topology stored at '{output_topology_file}'")
+        logger.info(
+            f"[+] Topology updated. New topology stored at '{output_topology_file}'"
+        )
     except Exception as e:
-        print(f"Error when adding websites to a topology: '{e}'")
+        logger.info(f"Error when adding websites to a topology: '{e}'")
         sys.exit(1)
 
 
@@ -846,16 +863,16 @@ def topo_add_dga_handler(args: Any) -> None:
         # Verify that the destination folder does not exist
         proceed = True
         if os.path.exists(resources_dir):
-            print(f"{resources_dir} already exists. It will be replaced.")
+            logger.info(f"{resources_dir} already exists. It will be replaced.")
             while (reply := input("Continue? [y/n]").lower()) not in {"y", "n"}:
-                print(f"{resources_dir} already exists. It will be replaced.")
+                logger.info(f"{resources_dir} already exists. It will be replaced.")
             if reply == "y":
                 proceed = True
             if reply == "n":
                 proceed = False
 
             if not proceed:
-                print("Stopping.")
+                logger.info("Stopping.")
                 sys.exit(1)
             else:
                 # remove resources_dir
@@ -865,7 +882,7 @@ def topo_add_dga_handler(args: Any) -> None:
                     else:
                         shutil.rmtree(resources_dir)
                 except OSError as e:
-                    print("Error: %s - %s." % (e.filename, e.strerror))
+                    logger.info("Error: %s - %s." % (e.filename, e.strerror))
 
         (topology_yaml, domains) = core_api.topology_file_add_dga(
             input_topology_file, algorithm, switch_name, number, resources_dir
@@ -873,7 +890,9 @@ def topo_add_dga_handler(args: Any) -> None:
         # write the topology
         with open(output_topology_file, "w") as w:
             w.write(topology_yaml)
-        print(f"[+] Topology updated. New topology stored at '{output_topology_file}'")
+        logger.info(
+            f"[+] Topology updated. New topology stored at '{output_topology_file}'"
+        )
 
         # write the resources (empty html file by default)
         resources_path = os.path.join(os.getcwd(), resources_dir)
@@ -924,40 +943,40 @@ def topo_add_dga_handler(args: Any) -> None:
             for d in domains:
                 nginx_conf.write(template_generated_domains.format(d))
 
-        print(f"[+] Resources created. They are stored at '{resources_path}'")
-        print(f"[+] Domains added: '{domains}'")
+        logger.info(f"[+] Resources created. They are stored at '{resources_path}'")
+        logger.info(f"[+] Domains added: '{domains}'")
 
     except Exception as e:
-        print(f"Error when adding domains to a topology: '{e}'")
+        logger.info(f"Error when adding domains to a topology: '{e}'")
         sys.exit(1)
 
 
 def set_core_api_url(core_api_url: str) -> str:
-    print("  [+] Using core API URL: {}".format(core_api_url))
+    logger.info("  [+] Using core API URL: {}".format(core_api_url))
     core_api.CORE_API_URL = core_api_url
     return core_api_url
 
 
 def set_scenario_api_url(scenario_api_url: str) -> str:
-    print("  [+] Using scenario API URL: {}".format(scenario_api_url))
+    logger.info("  [+] Using scenario API URL: {}".format(scenario_api_url))
     scenario_api.SCENARIO_API_URL = scenario_api_url
     return scenario_api_url
 
 
 def set_provisioning_api_url(provisioning_api_url: str) -> str:
-    print("  [+] Using provisioning API URL: {}".format(provisioning_api_url))
+    logger.info("  [+] Using provisioning API URL: {}".format(provisioning_api_url))
     provisioning_api.PROVISIONING_API_URL = provisioning_api_url
     return provisioning_api_url
 
 
 def set_redteam_api_url(redteam_api_url: str) -> str:
-    print("  [+] Using redteam API URL: {}".format(redteam_api_url))
+    logger.info("  [+] Using redteam API URL: {}".format(redteam_api_url))
     redteam_api.REDTEAM_API_URL = redteam_api_url
     return redteam_api_url
 
 
 def set_cacert(cacert: str) -> str:
-    print("  [+] Using CA certs path: {}".format(cacert))
+    logger.info("  [+] Using CA certs path: {}".format(cacert))
     core_api.CA_CERT_PATH = cacert
     scenario_api.CA_CERT_PATH = cacert
     provisioning_api.CA_CERT_PATH = cacert
@@ -966,7 +985,7 @@ def set_cacert(cacert: str) -> str:
 
 
 def set_cert(cert: str) -> str:
-    print("  [+] Using client cert path: {}".format(cert))
+    logger.info("  [+] Using client cert path: {}".format(cert))
     core_api.CLIENT_CERT_PATH = cert
     scenario_api.CLIENT_CERT_PATH = cert
     provisioning_api.CLIENT_CERT_PATH = cert
@@ -975,7 +994,7 @@ def set_cert(cert: str) -> str:
 
 
 def set_key(key: str) -> str:
-    print("  [+] Using client key path: {}".format(key))
+    logger.info("  [+] Using client key path: {}".format(key))
     core_api.CLIENT_KEY_PATH = key
     scenario_api.CLIENT_KEY_PATH = key
     provisioning_api.CLIENT_KEY_PATH = key
@@ -991,7 +1010,7 @@ def main() -> None:
     args, left_argv = parser.parse_known_args()
     if args.config:
         configfile_path = args.config
-        print(f"  [+] Using config file: {configfile_path}")
+        logger.info(f"  [+] Using config file: {configfile_path}")
         if not os.path.exists(configfile_path):
             raise Exception(f"Path '{configfile_path}' does not exist.")
         config = configparser.SafeConfigParser()
