@@ -28,6 +28,7 @@ from typing import Optional
 
 import requests
 from colorama import Fore
+from loguru import logger
 
 # Configuration access to Cyber Range endpoint
 REDTEAM_API_URL = "http://127.0.0.1:5004"
@@ -88,7 +89,7 @@ def _delete(route: str, **kwargs: str) -> requests.Response:
 
 def _handle_error(result: requests.Response, context_error_msg: str) -> None:
     if result.headers.get("content-type") == "application/json":
-        error_msg = str(result.json())  #["message"]
+        error_msg = str(result.json())  # ["message"]
     else:
         error_msg = result.text
 
@@ -115,7 +116,7 @@ def get_notification() -> dict:
 
 
 def available_attacks() -> List[str]:
-    url = "/attack/"
+    url = "/attack"
 
     result = _get(url, headers={}, data={})
 
@@ -143,7 +144,7 @@ def waiting_attack(id_attack: str, name: str, waiting_worker: bool = True) -> st
 
         status = result.json().get("status", None)
         if status == "waiting":
-            print(f"({id_attack}) Attack {name} is waiting.")
+            logger.info(f"[+] ({id_attack}) Attack {name} is waiting.")
             if not waiting_worker:
                 return status
 
@@ -154,8 +155,8 @@ def waiting_attack(id_attack: str, name: str, waiting_worker: bool = True) -> st
     elif status == "failed":
         color = Fore.RED
 
-    print(
-        f"{Fore.BLUE}({id_attack}) Attack {name}{Fore.RESET} : {color}{status}{Fore.RESET}"
+    logger.info(
+        f"[+] {Fore.BLUE}({id_attack}) Attack {name}{Fore.RESET} : {color}{status}{Fore.RESET}"
     )
     return status
 
@@ -169,12 +170,12 @@ def execute_attack(
     result = _get(url, headers=headers, data=payload)
 
     if result.status_code != 200:
-        _handle_error(result, "Cannot retrieve start attack from redteam API")
+        _handle_error(result, "Cannot start attack from redteam API")
 
     result = result.json()
     idAttack = result.get("idAttack", None)
-    print(f"{Fore.BLUE}({idAttack}) Attack {name}{Fore.RESET} : started")
-    print(f"    Values : {Fore.YELLOW}{result['values']}{Fore.RESET}")
+    logger.info(f"[+] {Fore.BLUE}({idAttack}) Attack {name}{Fore.RESET} : started")
+    logger.info(f"[+]     Values : {Fore.YELLOW}{result['values']}{Fore.RESET}")
     if idAttack is not None:
         return waiting_attack(idAttack, name, waiting_worker)
 
@@ -193,7 +194,7 @@ def execute_attack_name(attack_name: str, waiting_worker: bool = True) -> Option
     if attack:
         return execute_attack(attack["idAttack"], attack_name, waiting_worker)
     else:
-        print(f"Attack {attack_name} not avalaible")
+        logger.warning(f"[-] Attack {attack_name} not avalaible")
 
 
 def execute_attack_with_value(
@@ -223,7 +224,7 @@ def execute_attack_with_value(
             waiting_worker=waiting_worker,
         )
     else:
-        print(f"{Fore.RED} Attack {attack_name} not found.{Fore.RESET}")
+        logger.warning(f"[-] {Fore.RED} Attack {attack_name} not found.{Fore.RESET}")
 
 
 def init_knowledge(data: List) -> bool:
@@ -260,7 +261,7 @@ def execute_scenario(attack_list: List) -> bool:
                     execute_attack_name(key, waiting_worker=waiting)
         else:
             if execute_attack_name(elt) == "failed":
-                print(f"Scenario failed : {elt}")
+                logger.error(f"[-] Scenario failed : {elt}")
                 return False
     return True
 
@@ -273,14 +274,14 @@ def execute_scenario_by_yaml(yaml_content: Dict) -> bool:
     if attacks:
         return execute_scenario(attacks)
     else:
-        print("Missing attacks attribute")
+        logger.error("[-] Missing attacks attribute")
         return False
 
 
 def scenario_result() -> str:
     """Get attack scenario result."""
 
-    url = "/report/"
+    url = "/report"
 
     result = _get(url, headers={}, data={})
 
